which annotations to use: "auto" means automatic annotations, "manual" means manual ones.
Alternatively, any othe list element containing annotations can be specified.
terms
IDs of ontology terms for which descendants are queried.
...
other parameters for ontologyIndex::get_descendants() function