Learn R Programming

ontoFAST (version 1.0.0)

paths_sunburst: Return ontology paths for characters

Description

Returns ontology paths for all characters. These paths can be used to create a sunburst plot of ontological dependencies.

Usage

paths_sunburst(
  ontology,
  annotations = "auto",
  exclude.terms = NULL,
  include.terms = NULL,
  use.chars = TRUE,
  sep = "-"
)

Arguments

ontology

ontology_index object with character annatotions included.

annotations

which annotations to use: "auto" means automatic annotations, "manual" means manual ones. Alternatively, any othe list element containing annotations can be specified.

exclude.terms

list of terms to exclude

include.terms

list of terms to include

use.chars

indicate whether character ids should be included in output

sep

separator used to delimit ontology terms

Value

Table.

Examples

Run this code
# NOT RUN {
ontology_partof=get_OBO(system.file("data_onto", "HAO.obo", package = "ontoFAST"),
extract_tags="everything", propagate_relationships = c("BFO:0000050"))
ontology_partof<-onto_process(ontology_partof, Sharkey_2011[,1], do.annot = F)
ontology_partof$annot_characters<-Sharkey_2011_annot
tb<-paths_sunburst(ontology_partof,
annotations = ontology_partof$annot_characters, exclude.terms=exclude_terms)
# library(sunburst)
sunburst(tb)
# }

Run the code above in your browser using DataLab